#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom rlang check_dots_empty0
#' @importFrom stats ave
#' @importFrom tibble new_tibble
## usethis namespace: end
NULL
